### Data exploration and manipulation

### Title
# 30 years of large river restoration: how long do restored floodplain channels 
# remain suitable for targeted rheophilic fish in the lower river Rhine? 

### Authors
# T. Stoffers, F.P.L. Collas, G.W. Geerling, A.D. Buijse, L.H. Jans, 
# N. van Kessel, J.A.J. Verreth,  L.A.J. Nagelkerke

# Set path for packages
.libPaths('C:/Software/R')

# Set working directory
#setwd("m:\\My Documents\\Projecten\\Twan\\Analyse") #Leo
setwd("C:\\Users\\Stoff004\\OneDrive - WageningenUR\\2020 30 jaar geulen paper\\Analyse\\Analyse R") #Twan

# Empty the environment
remove(list=ls(all=TRUE))  #remove all objects

# load packages
library(plyr)  
library(dplyr)
library(corrplot)
library(vegan)
library(reshape2)
library(ggplot2)
library(MASS)
library(tidyr)
library(scales)
library(psych)
library(cowplot)

# Read raw data files
visdata_alles <- read.csv(file='MASTER_vis_totaal.csv') 
locatieinfo_alles <- read.csv(file='MASTER_locatie_totaal.csv') 
speciesnames <- read.csv(file='species.csv')
habitat_overzicht <- read.csv(file="Habitat_overzicht.csv")

# Merge files
alldata1 <- merge(locatieinfo_alles, visdata_alles, by="ID") #combine fish and habitat data
alldata2 <- merge(alldata1, speciesnames[,1:2], by="Volledige.naam") #remove mistakes in fish names (and crustacae) by correcting with list of all possible fishname mistakes

# Cut-off not necessary (compare with MWTL dataset and neglectible amounts of adult fish caught) 
# Merge with species file and correct for spelling mistakes
species_info <- read.csv(file='species2.csv')
alldata3 <- merge(alldata2, species_info, by="Soortnaam")

# Select for Summer season + Seine net + Secondary channel/Oxbow + Daytime sampling
alldata4 <- alldata3[which(alldata3$Seizoen=="Zomer" 
                           & (alldata3$Vangtuig =="Zegen - 75m" | alldata3$Vangtuig=="Broedzegen - 25m" | 
                                alldata3$Vangtuig=="Broedzegen - 16m" | alldata3$Vangtuig=="Zegen - 100m") 
                           & (alldata3$Type =="Nevengeul" | alldata3$Type =="Strang")
                           & alldata3$Dagdeel=="Dag"),-2]
fishdata1 <- subset(alldata4, select=c(Soortnaam, ID, Locatienr, Naam,Bevist.opp,
                                       Jaar, Type, Aantal)) # Select relevant variables for further analysis

# Calculate per location per year total fish numbers
fishdata2 <- ddply(.data=fishdata1, .(Soortnaam, ID,  Naam, Bevist.opp, Locatienr, Jaar, Type), summarize, totaal_aantal=sum(Aantal)) # Sum fish numbers per species per location
fishdata3 <- dcast(fishdata2, ID + Locatienr + Naam + Bevist.opp + Locatienr + Jaar + Type ~ Soortnaam, value.var="totaal_aantal") # create data frame with one row for location and fish species as columns 
fishdata3[is.na(fishdata3)] <- 0 #Replace NA with 0 
fishdata3a <- subset(fishdata3, select=-c(ID, Naam, Locatienr, Type)) # Temporarily remove location info for data transformation
fishdata3b <- unite(fishdata3a, Unique, c(Locatienr, Jaar), remove=FALSE) # Merge columns with location and year to create unique ID
fishdata3c <- subset(fishdata3b, select=-c(Locatienr, Jaar)) # Remove all variables except fish species and newly created ID
fishdata3d <- fishdata3c %>%
                group_by(Unique) %>%
                summarise_each(funs(sum)) # Sum fish and sample area (!) per species per unique variable
fishdata3e <- data.frame(fishdata3d,do.call(rbind,strsplit(fishdata3d$Unique,"_"))) # Split unique ID in 2 columns: Locatienr (X1) and Jaar (X2)
fishdata3e <- fishdata3e[,c(44,45,1:43)] # Rearrange dataset -> Locatie and Jaar as first 2 columns
fishdata3e <- subset(fishdata3e, select=-c(Unique)) # Remove column with Unique ID
names(fishdata3e)[1]<-paste("Locatienr") # Rename X1 --> Locatienr
names(fishdata3e)[2]<-paste("Jaar") # Rename X2 --> Jaar
fishdata3f <- merge(habitat_overzicht, fishdata3e, by=c("Locatienr","Jaar")) # Add location information to calculate delta t

# Correct for surface area - calculate for numbers per species per 100m2
fishdata3f[-c(1:26)] <- t(apply(fishdata3f[-c(1:25)], 1, function(x) x[-1]/x[1]/100))

# Remove Hybride cyprinide -> don't know which species it is (ide/asp) + small amounts AND remove samples with no fish (only needed for standardizing catch data per location)
fishdata4<- subset(fishdata3f, select=-c(Hybride.cyprinide,Geen.vis))
fishdata4$Period <- "Anders"
fishdata4$Period <- ifelse(fishdata4$Jaar<=2000,"1. Grift",ifelse(fishdata4$Jaar>=2016,"3. Stoffers", "2. Dorenbosch")) # Add period based on year

#write.csv(fishdata4, file="overzicht_visvangsten.csv")

# Summarize fish numbers per guild excluding invasive species: Rheophilics, Eurytopics, Limnophilics

# All fish
fishdata4$Allfish <- rowSums(fishdata4[c(27:65)])

# Per ecological guild
fishdata4$Rheo    <- rowSums(fishdata4[c("Barbeel", "Blauwneus", "Bot", "Houting", "Kleine.modderkruiper", "Kopvoorn", "Riviergrondel",
                                         "Serpeling", "Sneep", "Spiering", "Winde")])
fishdata4$Eury    <- rowSums(fishdata4[c("Aal", "Alver", "Baars", "Blankvoorn", "Blauwband", "Brasem", "Driedoornige.stekelbaars", 
                                         "Giebel", "Karper", "Kolblei", "Meerval", "Pos", "Rivierdonderpad", "Roofblei", "Snoek", 
                                         "Snoekbaars", "Zonnebaars")]) 
fishdata4$Limno   <- rowSums(fishdata4[c("Bittervoorn", "Kroeskarper", "Ruisvoorn", "Tiendoornige.stekelbaars", "Vetje", "Zeelt")])

# Let's include invasive species (gobies + whitefin gudgeon) in the ecological guilds
fishdata4$Rheo2    <- rowSums(fishdata4[c("Barbeel", "Blauwneus", "Bot", "Houting", "Kleine.modderkruiper", "Kopvoorn", "Riviergrondel",
                                         "Serpeling", "Sneep", "Spiering", "Winde", "Witvingrondel")])
fishdata4$Eury2    <- rowSums(fishdata4[c("Aal", "Alver", "Baars", "Blankvoorn", "Blauwband", "Brasem", "Driedoornige.stekelbaars", 
                                         "Giebel", "Karper", "Kolblei", "Meerval", "Pos", "Rivierdonderpad", "Roofblei", "Snoek", 
                                         "Snoekbaars", "Zonnebaars", "Kesslers.grondel", "Marmergrondel", "Pontische.stroomgrondel",
                                         "Zwartbekgrondel")]) 
fishdata4$Limno2   <- rowSums(fishdata4[c("Bittervoorn", "Kroeskarper", "Ruisvoorn", "Tiendoornige.stekelbaars", "Vetje", "Zeelt")])

# Select locations to include in paper
locatie_overzicht_paper <- subset(fishdata4, Naam == "Klompenwaard - nevengeul" | Naam == "Ewijkse Plaat" | Naam == "Beneden Leeuwen - nevengeul" | 
         Naam == "Passewaaij - nevengeul" | Naam == "Opijnen - nevengeul" | Naam == "Gameren - westelijke nevengeul" | 
         Naam == "Gameren - grote nevengeul" | Naam == "Duursche waarden - strang" | Naam == "Vreugderijkerwaard - nevengeul" | 
         Naam == "Scherenwelle" | Naam == "Bakenhof - nevengeul" | Naam == "Blauwe Kamer - strang")

#write.csv(locatie_overzicht_paper, file="locatie_overzicht_paper.csv" )


# Calculate geometric mean of abundances per period per location
fishdata5a <- melt(fishdata4[,c("Naam", "Delta_t", "Type", "Period",
                                "Barbeel", "Kopvoorn", "Riviergrondel", 
                                "Serpeling", "Sneep", "Winde","Witvingrondel",
                                "Allfish", "Rheo", "Eury",
                                "Limno", "Rheo2", "Eury2",
                                "Limno2")], 
                   id.vars=c("Period","Naam","Delta_t","Type"), 
                   variable.name="Guild") # Transpose data for calculating geometric mean

colnames(fishdata5a)[6] <- "Abundance"

min_abund <- min(fishdata5a$Abundance[which(fishdata5a$Abundance!=0)]) # Calculate mean abundance for removal of zero values later on (plus 0.5*min_abundance)
fishdata6a <- ddply(fishdata5a, .(Naam,Period,Guild),summarise, mean_ab=geometric.mean(Abundance+0.5*min_abund),meandelta=mean(Delta_t)) # Calculate geometric mean per guild per location per period
fishdata7a <- dcast(fishdata6a,Period+Naam+meandelta~Guild, value.var="mean_ab") # Transpose back to original format with fish guilds in columns

# Summarize unique species numbers/richness per guild per period per location (Rheophiles, Eurytopic, Limnophyles and Gobies)
fishdata5b <- melt(fishdata4[,c(3,6,8,66, 27:65)], id.vars=c("Period","Naam","Delta_t","Type"), variable.name="Species") # Transpose data for calculating unique species richness PER PERIOD (not year)
colnames(fishdata5b)[6] <- "Abundance"
fishdata5b$Spec_nr <- 0 # Introduce species richness column
fishdata5b$Spec_nr <- ifelse(fishdata5b$Abundance==0,0,1) # Present/absent per fish species
fishdata6b <- ddply(fishdata5b, .(Naam,Period,Species,Type),summarise, max_sp=max(Spec_nr)) # Select maximum nr of species per location and period
fishdata6c <- fishdata6b[which(fishdata6b$max_sp!=0),] # Remove data point with zero values for certain species
fishdata6c_1 <- fishdata6b[which(fishdata6b$max_sp!=0),] # Create separate file for species richness calculation with invasive gobies
fishdata6d <- ddply(fishdata6c, .(Naam,Period,Type), summarise, Spec_Allfish=sum(max_sp)) # Transpose data back and summarise species numbers for All fish per data point

# Create vectors for fish guilds for grouping fish species in species richness analysis
Rheo <- c("Barbeel", "Blauwneus", "Bot", "Houting", "Kleine.modderkruiper", "Kopvoorn", "Riviergrondel",
          "Serpeling", "Sneep", "Spiering", "Winde")
Eury <- c("Aal", "Alver", "Baars", "Blankvoorn", "Blauwband", "Brasem", "Driedoornige.stekelbaars", 
          "Giebel", "Karper", "Kolblei", "Meerval", "Pos", "Rivierdonderpad", "Roofblei", "Snoek", 
          "Snoekbaars", "Zonnebaars")
Limno <- c("Bittervoorn", "Kroeskarper", "Ruisvoorn", "Tiendoornige.stekelbaars", "Vetje", "Zeelt")

fishdata6c$Gilde <- "Anders"
fishdata6c$Gilde <- ifelse(fishdata6c$Species %in% Rheo, 
                           "Spec_Rheo",ifelse(fishdata6c$Species %in% Limno, 
                                              "Spec_Limno",ifelse(fishdata6c$Species %in% Eury,
                                                                  "Spec_Eury", NA))) # Assign individual fish species to guilds
                                                                                     # NA for invasive gobies and whitefin gudgeon
fishdata6c <- fishdata6c[complete.cases(fishdata6c), ] # Remove gobies rows (with NA)
fishdata6e <- ddply(fishdata6c, .(Naam,Period,Type,Gilde), summarise, Sp_number=sum(max_sp)) # Calculate species numbers per guild per location
fishdata6f <- dcast(fishdata6e,Period+Naam+Type~Gilde, value.var="Sp_number") # Cast to dataframe with Guilds as columns
fishdata6g <- merge(fishdata6f,fishdata6d) # Add species numbers for Allfish, calculated earlier
fishdata6g[is.na(fishdata6g)] <- 0 #Replace NA with 0 


# Species richness calculations including invasive gobies and whitefin gudgeon
Rheo2 <- c("Barbeel", "Blauwneus", "Bot", "Houting", "Kleine.modderkruiper", "Kopvoorn", "Riviergrondel",
           "Serpeling", "Sneep", "Spiering", "Winde", "Witvingrondel")
Eury2 <- c("Aal", "Alver", "Baars", "Blankvoorn", "Blauwband", "Brasem", "Driedoornige.stekelbaars", 
           "Giebel", "Karper", "Kolblei", "Meerval", "Pos", "Rivierdonderpad", "Roofblei", "Snoek", 
           "Snoekbaars", "Zonnebaars", "Kesslers.grondel", "Marmergrondel", "Pontische.stroomgrondel",
           "Zwartbekgrondel")
Limno2 <- c("Bittervoorn", "Kroeskarper", "Ruisvoorn", "Tiendoornige.stekelbaars", "Vetje", "Zeelt")

fishdata6c_2 <- fishdata6c_1
fishdata6c_2$Gilde <- "Anders"
fishdata6c_2$Gilde <- ifelse(fishdata6c_2$Species %in% Rheo2, 
                            "Spec_Rheo2",ifelse(fishdata6c_2$Species %in% Limno2, 
                                               "Spec_Limno2",ifelse(fishdata6c_2$Species %in% Eury2,
                                                                   "Spec_Eury2", NA))) # Assign individual fish species to guilds
                                                                                      # NA for invasive gobies and whitefin gudgeon
fishdata6c_2 <- fishdata6c_2[complete.cases(fishdata6c_2), ] # Remove gobies rows (with NA)
fishdata6e_2 <- ddply(fishdata6c_2, .(Naam,Period,Type,Gilde), summarise, Sp_number=sum(max_sp)) # Calculate species numbers per guild per location
fishdata6f_2 <- dcast(fishdata6e_2, Period+Naam+Type~Gilde, value.var="Sp_number") # Cast to dataframe with Guilds as columns
fishdata6f_2[is.na(fishdata6f_2)] <- 0 #Replace NA with 0 

fishdata6g <- merge(fishdata6g, fishdata6f_2, by=c("Period","Naam","Type"))

# Create master dataset for fish
master_datafile <- merge(fishdata7a, fishdata6g, by=c("Period","Naam")) # Merge species abundance and species numbers
colnames(master_datafile)[3] <- "Delta_t"
options(scipen=999)
master_datafile <- master_datafile[c(1,2,3,18,4:17,19:25)] # Rearrange data file
summary(master_datafile)
#write.csv(master_datafile, file="master_datafile.csv" )

# Add habitat data to master dataset
master_habitat_overzicht <- read.csv(file="master_habitat_overzicht.csv")
data <- merge(master_habitat_overzicht, master_datafile[-c(3,4)], by=c("Period","Naam"))
summary(data)


# Some housekeeping - renaming column names and Dutch names

# Habitat
colnames(data)[2] <- "Name"
colnames(data)[4] <- "River"
colnames(data)[6] <- "Connectivity"
colnames(data)[7] <- "Water_flow"
colnames(data)[8] <- "Mean_flow"
colnames(data)[10] <- "Length"
colnames(data)[11] <- "Width"
colnames(data)[12] <- "Surface_area"
colnames(data)[13] <- "Shore_length"
colnames(data)[14] <- "Shore_vegetation"
colnames(data)[15] <- "Shore_steepness"
colnames(data)[16] <- "Waterplants"
colnames(data)[20] <- "Habitat_heterogeneity"
colnames(data)[21] <- "Inlet_type"
colnames(data)[22] <- "Inflow_angle"
data$Type <- gsub("Nevengeul", "2SC", data$Type) # 2SC = two-sided connected channel
data$Type <- gsub("Strang", "1SC", data$Type) # 1SC = one-sided connected channel

# Locations
data$Name <- gsub("Bakenhof - nevengeul", "BH", data$Name)
data$Name <- gsub("Beneden Leeuwen - nevengeul", "BL", data$Name)
data$Name <- gsub("Blauwe Kamer - strang", "BK", data$Name)
data$Name <- gsub("Duursche waarden - strang", "DW", data$Name)
data$Name <- gsub("Ewijkse Plaat", "EP", data$Name)
data$Name <- gsub("Gameren - grote nevengeul", "GG", data$Name)
data$Name <- gsub("Gameren - westelijke nevengeul", "GW", data$Name)
data$Name <- gsub("Klompenwaard - nevengeul", "KL", data$Name)
data$Name <- gsub("Opijnen - nevengeul", "OP", data$Name)
data$Name <- gsub("Passewaaij - nevengeul", "PA", data$Name)
data$Name <- gsub("Scherenwelle", "SW", data$Name)
data$Name <- gsub("Vreugderijkerwaard - nevengeul", "VR", data$Name)

# Fish
colnames(data)[23] <- "Barbel"
colnames(data)[24] <- "Chub"
colnames(data)[25] <- "Gudgeon"
colnames(data)[26] <- "Dace"
colnames(data)[27] <- "Nase"
colnames(data)[28] <- "Ide"
colnames(data)[29] <- "Whitefin_gudgeon"

#write.csv(data, file="Stoffers2020_final_data.csv")

